package com.ruoyi.system.service.impl;

import com.ruoyi.system.mapper.WagesConversionMapper;
import com.ruoyi.system.model.wages.dao.WagesConversionData;
import com.ruoyi.system.model.wages.dto.WagesParamsDto;
import com.ruoyi.system.model.wages.vo.WagesConversionDataVO;
import com.ruoyi.system.service.WagesConversionService;
import org.springframework.stereotype.Service;

import java.util.Collections;
import java.util.List;
import java.util.Optional;
import java.util.stream.Collectors;

/**
 * 2024/5/11
 */
@Service
public class WagesConversionServiceImpl implements WagesConversionService {
    private WagesConversionMapper wagesConversionMapper;

    private WagesConversionServiceImpl(WagesConversionMapper wagesConversionMapper) {
        this.wagesConversionMapper = wagesConversionMapper;
    }

    @Override
    public void save(WagesConversionDataVO wagesConversionDataVO) {
        wagesConversionMapper.deleteFromConversionToDate(wagesConversionDataVO.getYearMonth());
        wagesConversionMapper.save(wagesConversionDataVO.getJsonData(), wagesConversionDataVO.getYearMonth(), wagesConversionDataVO.getValue(), wagesConversionDataVO.getMineId());
    }

    @Override
    public List<WagesConversionData> selectWagesConversionDataList(WagesParamsDto wagesParamsDto) {
        String pageNum = wagesParamsDto.getPageNum();
        String pageSize = wagesParamsDto.getPageSize();
        String wageMonth = wagesParamsDto.getWageMonth();
        int n = (Integer.parseInt(pageNum) - 1) * Integer.parseInt(pageSize);
        return wagesConversionMapper.selectWagesConversionDataList(n, Integer.parseInt(pageSize), wageMonth, wagesParamsDto.getMineId());
    }

    @Override
    public void update(WagesConversionData wagesConversionData) {
        String jsonData = wagesConversionData.getJsonData();
        int id = wagesConversionData.getId();
        wagesConversionMapper.update(id, jsonData);
    }

    @Override
    public WagesConversionData selectWagesConversionDataById(int id) {
        return wagesConversionMapper.selectWagesConversionDataById(id);
    }

    @Override
    public Object recentFormulas() {
        List<WagesConversionDataVO> list = wagesConversionMapper.selectWagesValueAndDate();
        list.removeAll(Collections.singleton(null));
        boolean b1 = list.parallelStream().anyMatch(v -> v.getYearMonth() == null || v.getYearMonth().indexOf("-") <= 0);
        if (b1) return "数据库中数据存在日期错误";
        Optional<Integer> max = list.parallelStream().map(v -> Integer.parseInt(v.getYearMonth().split("-")[0])).max((a, b) -> a - b);
        List<WagesConversionDataVO> collect;
        if (max.isPresent()) {
            collect = list.parallelStream().filter(v -> v.getYearMonth().split("-")[0].equals(max.get() + "")).collect(Collectors.toList());
        } else {
            return "数据库中没有数据";
        }
        if (collect != null) {
            collect = collect.parallelStream().sorted((a, b) -> Integer.parseInt(b.getYearMonth().split("-")[1]) - Integer.parseInt(a.getYearMonth().split("-")[1])).collect(Collectors.toList());
        }
        return collect.get(0).getValue();
    }

}
